==> nextcloud-12.0.2.tgz: nextcloud/apps/gallery/l10n/hu.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galéria",
    "There was a problem reading files from this album" : "Hiba történt az albumból való fájl olvasás közben",
    "Aborting preview. Could not find the file" : "Előnézet megszakítása. Nem található a fájl",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "No compatible server found at {remote}" : "Itt nem található kompatibilis szerver: {remote}",
    "Invalid server url" : "Érvénytelen szerver URL",
    "Could not load the description" : "Nem lehet betölteni a leírást",
    "Could not load the description: " : "Nem lehet betölteni a leírást:",
    "Copyright" : "Szerzői jog",
    "Could not load the copyright notice: " : "Nem lehet betölteni a szerzői jogokat:",
    "Copyright notice" : "Szerzői jogi nyilatkozat",
    "Link to copyright document" : "Hivatkozás a szerzői jogokra vonatkozó dokumentumra",
    "This application may not work properly on your browser." : "Ez az alkalmazás valószínűleg nem fog működni a böngészőjével.",
    "For an improved experience, please install one of the following alternatives" : "A jobb teljesítmény érdekében, kérlek telepíts egy alternatívát a következők közül",
    "Your browser is not supported!" : "A böngészője nem támogatott!",
    "please install one of the following alternatives" : "kérlek telepíts egy alternatívát a következők közül",
    "Album cannot be shown" : "Az album nem jeleníthető meg",
    "No media files found" : "Nem található média fájl",
    "Upload new files via drag and drop or by using the [+] button above" : "Töltsön fel új fájlokat ráhúzással, vagy használja a [+] gombot",
    "Configuration error" : "Beállítási hiba",
    "New" : "Új",
    "Hide Album" : "Album elrejtése",
    "Could not hide album" : "Az album nem rejthető el",
    "Error loading slideshow template" : "Hiba történt a diasor sablonjának betöltésekor",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Hiba!</strong>Nem készíthető előnézet a fájlról.<br>Kérlek, menj a következő diára, amíg eltávolítjuk ezt a képet a diavetítésből.",
    "Next" : "Következő",
    "Play" : "Lejátszás",
    "Pause" : "Szünet",
    "Previous" : "Előző",
    "Close" : "Bezárás",
    "Download" : "Letöltés",
    "Toggle background" : "Háttér ki/be kapcsolása",
    "Delete" : "Törlés",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nem engedélyetett fájltípus",
    "Upload" : "Feltöltés",
    "Error" : "Hiba",
    "Error while sharing" : "Nem sikerült létrehozni a megosztást",
    "Error while unsharing" : "Nem sikerült visszavonni a megosztást",
    "Error while changing permissions" : "Nem sikerült módosítani a jogosultságokat",
    "Shared with you and the group {group} by {owner}" : " {owner} megosztotta veled és ezzel a csoporttal: {group}",
    "Shared with you by {owner}" : "Megosztotta veled: {owner}",
    "Share with users or groups …" : "Megosztás felhasználókkal vagy csoportokkal ...",
    "Share with users, groups or remote users …" : "Megosztás felhasználókkal, csoportokkal vagy távoli felhasználókkal ...",
    "Share" : "Megosztás",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Megosztás más szervert használó emberekkel, az Egyesített Felhő Azonosítóval: username@example.com/cloud",
    "Share link" : "Megosztás hivatkozással",
    "The public link will expire no later than {days} days after it is created" : "A nyilvános hivatkozás érvényessége legkorábban {days} nappal a létrehozása után jár csak le",
    "Link" : "Hivatkozás",
    "Password protect" : "Jelszóval is védem",
    "Password" : "Jelszó",
    "Choose a password for the public link" : "Válasszon egy jelszót a nyilvános hivatkozáshoz",
    "Allow editing" : "Szerkesztheti",
    "Email link to person" : "Hivatkozás küldése e-mailben",
    "Send" : "Küldés",
    "Set expiration date" : "Legyen lejárati idő",
    "Expiration" : "Lejárat",
    "Expiration date" : "Lejárati idő",
    "No users or groups found for {search}" : "{search} keresésre nem található felhasználó vagy csoport ",
    "No users found for {search}" : "{search} keresésre nem található felhasználó ",
    "An error occured. Please try again" : "Hiba történt. Kérjük, próbálja újra!",
    "Adding user..." : "Felhasználó hozzáadása...",
    "group" : "csoport",
    "remote" : "távoli",
    "Resharing is not allowed" : "Ezt a fájlt csak a tulajdonosa oszthatja meg másokkal",
    "Error while retrieving shares" : "Hiba történt a megosztások lekérése közben",
    "Unshare" : "A megosztás visszavonása",
    "notify by email" : "e-mail értesítés",
    "can share" : "megoszthatja",
    "can edit" : "szerkesztheti",
    "access control" : "jogosultság kezelés",
    "create" : "létrehozás",
    "change" : "módosít",
    "delete" : "törlés",
    "Password protected" : "Jelszóval védett",
    "Error unsetting expiration date" : "Nem sikerült a lejárati időt törölni",
    "Error setting expiration date" : "Nem sikerült a lejárati időt beállítani",
    "Sending ..." : "Küldés ...",
    "Email sent" : "Az e-mail elküldve!",
    "Warning" : "Figyelmeztetés",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Sort by date" : "Rendezés dátum szerint",
    "Sort by name" : "Rendezés név szerint",
    "Cancel upload" : "A feltöltés megszakítása",
    "Album information" : "Album információ",
    "File list" : "Fájllista",
    "Sorry, this file could not be found." : "Sajnáljuk, de a fájl nem található.",
    "Reasons might be:" : "Ez a következők miatt lehet:",
    "the wrong file ID was provided" : "rossz fájl azonosító lett közölve",
    "the file was removed" : "a fájlt törölték",
    "the file is corrupt" : "a fájl korrupt",
    "the encryption key is missing" : "a titkosító kulcs hiányzik",
    "Here is the error message returned by the server: " : "Ezzel a hibaüzenettel tért vissza a szerver:",
    "For more information, please contact your friendly Nextcloud administrator." : "Bővebb információért, kérjük keresd fel a barátságos Nextcloud rendszergazdát.",
    "Sorry, but the server could not fulfill your request." : "Sajnáljuk, de a szerver nem tudta teljesíteni a kérését.",
    "Possible reasons for the problem:" : "A probléma lehetséges okai:",
    "a conflicting app was installed" : "ütköző alkalmazás lett telepítve",
    "a required component is missing or was disconnected" : "szükséges követelmény hiányzik, vagy szétkapcsolt",
    "the filesystem is not readable" : "a fájlrendszer nem olvasható",
    "Sorry, this link doesn't seem to work anymore." : "Sajnáljuk, de úgy tűnik, hogy ez a hivatkozás már nem működik.",
    "the item was removed" : "az elem el lett távolítva",
    "the link has expired" : "a hivatkozás lejárt",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more information, please ask the person who has sent you this link." : "Bővebb információért, kérjük keresse fel azt az embert, aki küldte ezt a hivatkozást.",
    "Add to your Nextcloud" : "Add hozzá a saját Nexcloudodhoz",
    "Picture view" : "Képnézet",
    "Gallery view" : "Galéria nézet"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/hu.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galéria",
    "There was a problem reading files from this album" : "Hiba történt az albumból való fájl olvasás közben",
    "Aborting preview. Could not find the file" : "Előnézet megszakítása. Nem található a fájl",
    "Could not move \"{file}\", target exists" : "{file} fájl nem áthelyezhető, mert a cél már létezik",
    "Could not move \"{file}\"" : "{file} fájl nem áthelyezhető",
    "No compatible server found at {remote}" : "Itt nem található kompatibilis szerver: {remote}",
    "Invalid server url" : "Érvénytelen szerver URL",
    "Could not load the description" : "Nem lehet betölteni a leírást",
    "Could not load the description: " : "Nem lehet betölteni a leírást:",
    "Copyright" : "Szerzői jog",
    "Could not load the copyright notice: " : "Nem lehet betölteni a szerzői jogokat:",
    "Copyright notice" : "Szerzői jogi nyilatkozat",
    "Link to copyright document" : "Hivatkozás a szerzői jogokra vonatkozó dokumentumra",
    "This application may not work properly on your browser." : "Ez az alkalmazás valószínűleg nem fog működni a böngészőjével.",
    "For an improved experience, please install one of the following alternatives" : "A jobb teljesítmény érdekében, kérlek telepíts egy alternatívát a következők közül",
    "Your browser is not supported!" : "A böngészője nem támogatott!",
    "please install one of the following alternatives" : "kérlek telepíts egy alternatívát a következők közül",
    "Album cannot be shown" : "Az album nem jeleníthető meg",
    "No media files found" : "Nem található média fájl",
    "Upload pictures in the Files app to display them here" : "Töltsön fel képeket a Fájlok alkalmazással, hogy itt megjelenjenek",
    "Upload new files via drag and drop or by using the [+] button above" : "Töltsön fel új fájlokat ráhúzással, vagy használja a [+] gombot",
    "Configuration error" : "Beállítási hiba",
    "New" : "Új",
    "Hide Album" : "Album elrejtése",
    "Could not hide album" : "Az album nem rejthető el",
    "Error loading slideshow template" : "Hiba történt a diasor sablonjának betöltésekor",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Hiba!</strong>Nem készíthető előnézet a fájlról.<br>Kérlek, menj a következő diára, amíg eltávolítjuk ezt a képet a diavetítésből.",
    "Next" : "Következő",
    "Play" : "Lejátszás",
    "Pause" : "Szünet",
    "Previous" : "Előző",
    "Close" : "Bezárás",
    "Download" : "Letöltés",
    "Toggle background" : "Háttér ki/be kapcsolása",
    "Delete" : "Törlés",
    "Share" : "Megosztás",
    "Could not create file \"{file}\" because it already exists" : "{file} fájl nem létrehozható, mert már létezik",
    "Could not create file \"{file}\"" : "{file} fájl nem létrehozható",
    "\"{name}\" is an invalid file name." : "\"{name}\" érvénytelen, mint fájlnév.",
    "File name cannot be empty." : "A fájlnév nem lehet semmi.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nem engedélyetett fájltípus",
    "Upload" : "Feltöltés",
    "Error" : "Hiba",
    "Error while sharing" : "Nem sikerült létrehozni a megosztást",
    "Error while unsharing" : "Nem sikerült visszavonni a megosztást",
    "Error while changing permissions" : "Nem sikerült módosítani a jogosultságokat",
    "Shared with you and the group {group} by {owner}" : " {owner} megosztotta veled és ezzel a csoporttal: {group}",
    "Shared with you by {owner}" : "Megosztotta veled: {owner}",
    "Share with users or groups …" : "Megosztás felhasználókkal vagy csoportokkal ...",
    "Share with users, groups or remote users …" : "Megosztás felhasználókkal, csoportokkal vagy távoli felhasználókkal ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Megosztás más szervert használó emberekkel, az Egyesített Felhő Azonosítóval: username@example.com/cloud",
    "Share link" : "Megosztás hivatkozással",
    "The public link will expire no later than {days} days after it is created" : "A nyilvános hivatkozás érvényessége legkorábban {days} nappal a létrehozása után jár csak le",
    "Link" : "Hivatkozás",
    "Password protect" : "Jelszóval is védem",
    "Password" : "Jelszó",
    "Choose a password for the public link" : "Válasszon egy jelszót a nyilvános hivatkozáshoz",
    "Allow editing" : "Szerkesztheti",
    "Email link to person" : "Hivatkozás küldése e-mailben",
    "Send" : "Küldés",
    "Set expiration date" : "Legyen lejárati idő",
    "Expiration" : "Lejárat",
    "Expiration date" : "Lejárati idő",
    "This list is maybe truncated - please refine your search term to see more results." : "Ez a lista lehet, hogy le van vágva - kérem pontosítsa a keresését, hogy több eredményt lásson.",
    "No users or groups found for {search}" : "{search} keresésre nem található felhasználó vagy csoport ",
    "No users found for {search}" : "{search} keresésre nem található felhasználó ",
    "An error occured. Please try again" : "Hiba történt. Kérjük, próbálja újra!",
    "Adding user..." : "Felhasználó hozzáadása...",
    "group" : "csoport",
    "remote" : "távoli",
    "Resharing is not allowed" : "Ezt a fájlt csak a tulajdonosa oszthatja meg másokkal",
    "Error while retrieving shares" : "Hiba történt a megosztások lekérése közben",
    "Unshare" : "A megosztás visszavonása",
    "notify by email" : "e-mail értesítés",
    "can share" : "megoszthatja",
    "can edit" : "szerkesztheti",
    "access control" : "jogosultság kezelés",
    "create" : "létrehozás",
    "change" : "módosít",
    "delete" : "törlés",
    "Password protected" : "Jelszóval védett",
    "Error unsetting expiration date" : "Nem sikerült a lejárati időt törölni",
    "Error setting expiration date" : "Nem sikerült a lejárati időt beállítani",
    "Sending…" : "Küldés...",
    "Email sent" : "Az e-mail elküldve!",
    "Warning" : "Figyelmeztetés",
    "This share is password-protected" : "Ez egy jelszóval védett megosztás",
    "The password is wrong. Try again." : "A megadott jelszó nem megfelelő. Próbálja újra!",
    "Sort by name" : "Rendezés név szerint",
    "Sort by date" : "Rendezés dátum szerint",
    "Cancel upload" : "A feltöltés megszakítása",
    "Album information" : "Album információ",
    "File list" : "Fájllista",
    "Sorry, this file could not be found." : "Sajnáljuk, de a fájl nem található.",
    "Reasons might be:" : "Ez a következők miatt lehet:",
    "the wrong file ID was provided" : "rossz fájl azonosító lett közölve",
    "the file was removed" : "a fájlt törölték",
    "the file is corrupt" : "a fájl korrupt",
    "the encryption key is missing" : "a titkosító kulcs hiányzik",
    "Here is the error message returned by the server: " : "Ezzel a hibaüzenettel tért vissza a szerver:",
    "For more information, please contact your friendly Nextcloud administrator." : "Bővebb információért, kérjük keresd fel a barátságos Nextcloud rendszergazdát.",
    "Sorry, but the server could not fulfill your request." : "Sajnáljuk, de a szerver nem tudta teljesíteni a kérését.",
    "Possible reasons for the problem:" : "A probléma lehetséges okai:",
    "a conflicting app was installed" : "ütköző alkalmazás lett telepítve",
    "a required component is missing or was disconnected" : "szükséges követelmény hiányzik, vagy szétkapcsolt",
    "the filesystem is not readable" : "a fájlrendszer nem olvasható",
    "Sorry, this link doesn't seem to work anymore." : "Sajnáljuk, de úgy tűnik, hogy ez a hivatkozás már nem működik.",
    "the item was removed" : "az elem el lett távolítva",
    "the link has expired" : "a hivatkozás lejárt",
    "sharing is disabled" : "letiltásra került a megosztás",
    "For more information, please ask the person who has sent you this link." : "Bővebb információért, kérjük keresse fel azt az embert, aki küldte ezt a hivatkozást.",
    "Add to your Nextcloud" : "Add hozzá a saját Nexcloudodhoz",
    "Picture view" : "Képnézet",
    "Gallery view" : "Galéria nézet",
    "Sending ..." : "Küldés ..."
},
"nplurals=2; plural=(n != 1);");
